PermissionSet

Struct PermissionSet 

pub struct PermissionSet {
    entries: Vec<PermissionEntry>,
    sources: Vec<PermissionResolutionSource>,
}
A flat effective permission set with deterministic conflict resolution.

Fields

entries: Vec<PermissionEntry>sources: Vec<PermissionResolutionSource>

Implementations

Source

impl PermissionSet

pub const fn new() -> Self

Creates an empty set. Unset permissions resolve to None and are denied by allows*.

pub fn from_entries(entries: impl IntoIterator<Item = PermissionEntry>) -> Self

Creates a set of direct subject rules.

pub fn entries(&self) -> &[PermissionEntry]

Returns all rules in insertion order.

pub fn push(&mut self, entry: PermissionEntry)

Adds a direct subject rule.

pub fn allow(&mut self, key: PermissionKey)

Adds a global direct allow.

pub fn allow_in(&mut self, key: PermissionKey, context: PermissionRuleContext)

Adds a contextual direct allow.

pub fn deny(&mut self, key: PermissionKey)

Adds a global direct deny.

pub fn deny_in(&mut self, key: PermissionKey, context: PermissionRuleContext)

Adds a contextual direct deny.

pub fn set(&mut self, key: PermissionKey, state: PermissionState)

Replaces the exact global rule for key.

pub fn set_in( &mut self, key: PermissionKey, context: PermissionRuleContext, state: PermissionState, )

Replaces the exact rule for key and context.

pub fn unset(&mut self, key: &PermissionKey) -> bool

Removes the exact global rule for key.

pub fn unset_in( &mut self, key: &PermissionKey, context: &PermissionRuleContext, ) -> bool

Removes the exact rule for key and context.

pub fn resolve_key(&self, key: &PermissionKey) -> Option<PermissionState>

Resolves one key globally.

pub fn resolve_key_in( &self, key: &PermissionKey, context: &PermissionContext, ) -> Option<PermissionState>

Resolves one key in an active context.

pub fn resolve_key_detailed( &self, key: &PermissionKey, ) -> Option<PermissionResolution>

Resolves one key globally and returns the winning rule details.

pub fn resolve_key_in_detailed( &self, key: &PermissionKey, context: &PermissionContext, ) -> Option<PermissionResolution>

Resolves one key in an active context and returns the winning rule details.

pub fn resolve_scoped_key( &self, parent: &PermissionKey, key: &PermissionKey, ) -> Option<PermissionState>

Resolves a child key that may inherit a broad parent grant.

pub fn resolve_scoped_key_in( &self, parent: &PermissionKey, key: &PermissionKey, context: &PermissionContext, ) -> Option<PermissionState>

Resolves a child key with a parent fallback in an active context.

pub fn resolve_scoped_key_detailed( &self, parent: &PermissionKey, key: &PermissionKey, ) -> Option<PermissionResolution>

Resolves a scoped child globally and returns the winning rule details.

pub fn resolve_scoped_key_in_detailed( &self, parent: &PermissionKey, key: &PermissionKey, context: &PermissionContext, ) -> Option<PermissionResolution>

Resolves a scoped child in an active context and returns winning rule details.

pub fn allows_key(&self, key: &PermissionKey) -> bool

Returns whether one global key resolves to allow.

pub fn allows_key_in( &self, key: &PermissionKey, context: &PermissionContext, ) -> bool

Returns whether one key resolves to allow in context.

pub fn allows_scoped_key( &self, parent: &PermissionKey, key: &PermissionKey, ) -> bool

Returns whether one scoped child resolves to allow globally.

pub fn allows_scoped_key_in( &self, parent: &PermissionKey, key: &PermissionKey, context: &PermissionContext, ) -> bool

Returns whether one scoped child resolves to allow in context.

pub fn allows(&self, permission: &PermissionExpr) -> bool

Returns whether a global permission expression resolves to allow.

pub fn allows_in( &self, permission: &PermissionExpr, context: &PermissionContext, ) -> bool

Returns whether an expression resolves to allow in context.

pub fn resolve(&self, permission: &PermissionExpr) -> Option<PermissionState>

Resolves a permission expression globally.

pub fn resolve_in( &self, permission: &PermissionExpr, context: &PermissionContext, ) -> Option<PermissionState>

Resolves a permission expression in context.

pub(super) fn push_group( &mut self, entry: PermissionEntry, group: &str, group_priority: i32, )

fn push_with_source( &mut self, entry: PermissionEntry, source: PermissionResolutionSource, )

fn retain_entries(&mut self, keep: impl FnMut(&PermissionEntry) -> bool)

fn best_key_candidate( &self, key: &PermissionKey, context: &PermissionContext, ) -> Option<PermissionCandidate>

fn best_scoped_key_candidate( &self, parent: &PermissionKey, key: &PermissionKey, context: &PermissionContext, ) -> Option<PermissionCandidate>

fn permission_resolution( &self, candidate: PermissionCandidate, ) -> PermissionResolution